from fastapi import APIRouter, Depends
from sqlalchemy.orm import Session

from app.db.session import get_db

router = APIRouter(tags=["health"])

@router.get("/health")
def health_check(db: Session = Depends(get_db)):
    """
    Health check endpoint to verify API is up and running and can connect to the database
    """
    try:
        # Try to connect to the database
        db.execute("SELECT 1")
        db_status = "up"
    except Exception:
        db_status = "down"
    
    return {
        "status": "ok",
        "database": db_status
    }