from datetime import datetime
from typing import Optional, List

from pydantic import BaseModel

from app.schemas.user import User

class ConversationBase(BaseModel):
    name: Optional[str] = None
    is_group: bool = False

class ConversationCreate(ConversationBase):
    participant_ids: List[str]

class ConversationUpdate(BaseModel):
    name: Optional[str] = None

class ConversationInDBBase(ConversationBase):
    id: str
    created_at: datetime
    updated_at: datetime

    class Config:
        orm_mode = True

class Conversation(ConversationInDBBase):
    participants: List[User]

class ConversationInDB(ConversationInDBBase):
    pass